"""

Test for attentionpoint objects

Meant to be subclassed

"""
from django.contrib.auth.models import User
from django.test import TestCase

from installations import models as installations_models

from utils import tests as utils_tests
from utils.versioning.models import WorkVersion, Version

class AttentionPointTest(TestCase):
    fixtures = ['dummyusers', 'installations']
##    sc_model = Scenario
##    pl_model = ProtectionLayer
##    me_model = Measure
##    ap_model = AttentionPoint
##    sl_model = Suggestionlist
##    namespace = "degradations"

    def setUp(self):
        self.setPermissions()
        defaultuser = User.objects.get(pk=1)
        self.scope = installations_models.Scope.objects.filter(version__isnull=True)[0]
        self.measure = self.me_model(name='PL', type='PL')
        self.measure.save(defaultuser)
        self.attentionpoint = self.ap_model(name='Capacity', type='Specification', measure=self.measure)
        self.attentionpoint.save(defaultuser)

        self.suggestionlist = self.sl_model(name='SL')
        self.suggestionlist.save(defaultuser)
        self.slmeasure = self.me_model(name='PL', type='PL', SL=True)
        self.slmeasure.save(defaultuser)
        self.slattentionpoint = self.ap_model(name='Capacity', type='Specification', measure=self.slmeasure)
        self.slattentionpoint.save(defaultuser)

    def test_model(self):
        # test SL denormalisation
        self.assertEquals(self.attentionpoint.SL, False)
        self.assertEquals(self.slattentionpoint.SL, True)

    def test_attentionpoint_views(self):
        base_url = '/analyses/%s/attentionpoints/' % self.namespace
        parent_url = '/analyses/%s/measures/%s/attentionpoints/' % (self.namespace, self.measure.v_id)
        defaultuser = User.objects.get(pk=1)
        users = (0,1,2,3)

        class attentionpoints(utils_tests.TestDefinition):
            description = 'list of attentionpoints'
            url = base_url
            users = [1,2,]
            contains = [{'url': base_url + 'add/', 'users': []},]

        class attentionpoints_report_select(utils_tests.TestDefinition):
            description = 'report of list of attentionpoints: select options'
            url = base_url + '?submit_pdf=submit_pdf&filter-name=FA'
            users = [1,2,]

        class attentionpoints_report(utils_tests.postonly_TestDefinition):
            description = 'pdf of list of attentionpoints'
            url = base_url
            users = [1,2,]
            data = {
                "filter": "submit_pdf=submit_pdf&filter-name=FA",
                "submit_pdf": "Generate pdf",
            }

        class attentionpoints_csv(utils_tests.postonly_TestDefinition):
            description = 'csv of list of attentionpoints'
            url = base_url
            users = [1,2,]
            data = {
                "filter": "filter-name=FA",
                "submit_csv": "Generate csv",
            }

        class attentionpoint(utils_tests.TestDefinition):
            description = 'display attentionpoint'
            url = base_url + '%s/' % self.attentionpoint.v_id
            users = [1,2,]
            contains = [
                {'url': base_url + '%s/edit/' % self.attentionpoint.v_id, 'users': [1,]},
                {'url': base_url + '%s/delete/' % self.attentionpoint.v_id, 'users': [1,]},
            ]

        class attentionpoint_compare(utils_tests.TestDefinition):
            description = 'compare attentionpoint'
            url = base_url + '%s/compare/0/' % self.attentionpoint.v_id
            users = [1,2,]

        class attentionpoint_add(utils_tests.add_TestDefinition):
            description = 'add attentionpoint'
            url = parent_url + 'add/'
            users = [1,]
            data = {
                "name": "Volume",
                "description": "",
                "type": "Specification",
                "management-referer": parent_url
            }
            redirect_url = parent_url

            def posttest(self, testcase, allowed):
                if allowed:
                    self.test_class.ap_model.objects.order_by('-id')[0].delete(testcase.user, override=True)

        class attentionpoint_edit(utils_tests.edit_TestDefinition):
            description = 'edit attentionpoint'
            url = base_url + '%s/edit/' % self.attentionpoint.v_id
            users = [1,]
            data = {
                "name": "Capacity",
                "description": "",
                "type": "Specification",
                "management-referer": base_url + '%s/' % self.attentionpoint.v_id
            }
            redirect_url = base_url + '%s/' % self.attentionpoint.v_id

        class attentionpoint_delete(utils_tests.delete_TestDefinition):
            description = 'delete attentionpoint'
            users = [1,]
            redirect_url = parent_url
            def pretest(self, testcase, allowed):
                newitem = self.test_class.ap_model(name='to_delete', measure=self.test_class.measure)
                newitem.save(defaultuser)
                self.pk = newitem.id
                self.url = base_url + '%s/delete/' % newitem.v_id
            def posttest(self, testcase, allowed):
                if not allowed:
                    self.test_class.ap_model.objects.get(id=self.pk).delete(defaultuser, override=True)

        class attentionpoint_report(utils_tests.TestDefinition):
            description = 'pdf report for attentionpoint'
            url = base_url + '%s/pdf/' % self.attentionpoint.v_id
            users = [1,2,]

        class attentionpoint_typelookup(utils_tests.TestDefinition):
            description = 'attentionpoint type lookup'
            url = base_url + 'type_lookup/'
            users = [1,2,]
            data = {
                "term": "pec",
            }
            contains = [
                {'url': 'Specification', 'users': [1,2,]},
            ]

        class attentionpoint_namelookup(utils_tests.TestDefinition):
            description = 'attentionpoint name lookup'
            url = base_url + 'name_lookup/'
            users = [1,2,]
            data = {
                "term": "cap",
            }
            contains = [
                {'url': 'Capacity', 'users': [1,2,]},
            ]

        tests = [
            attentionpoints(self),
            attentionpoints_report_select(self),
            attentionpoints_report(self),
            attentionpoints_csv(self),
            attentionpoint(self),
            attentionpoint_compare(self),
            attentionpoint_add(self),
            attentionpoint_edit(self),
            attentionpoint_delete(self),
            attentionpoint_report(self),
            attentionpoint_typelookup(self),
            attentionpoint_namelookup(self),
        ]

        utils_tests.run_tests(self, users, tests)

