# Deviation scenario views

from analyses.analysisbase.views import scenario as base_views

from analyses.deviations import models as app_models
from analyses.deviations import evaluation
from analyses.deviations import forms as app_forms
from analyses.deviations import tables as app_tables

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from utils import crud
from utils.trees import views as trees_views
from utils.versioning.models import WorkVersion
from utils.versioning import versionedcrud

class MixIn(object):
    "Common items for object views"
    appconfig = app_models.AppConfig
    model = appconfig.get_model('scenario')

   # Override from base_views
    def setup_tabs(self):
        self.tabs = self.basetabs[:]
        if self.object and not self.object.suggestionlist and self.basetabs:
            self.tabs.extend([
                {'name': 'evaluation',
                    'label': _('Evaluation')},
                {'name': 'lopa',
                    'label': _('LOPA')},
            ])

class display_scenario(MixIn, base_views.display_scenario):
    pass

class display_causetree(MixIn, base_views.display_causetree):
    def add_to_extra_context(self, extra_context, object):
        # skip add_to_extra_context from the analysisbase
        super(base_views.display_causetree, self).add_to_extra_context(extra_context, object)
        treeobjects = app_models.CauseTreeElement.tree.filter(scenario=object
            ).get_versionedobjects(version=self.version).select_related_versioned()
        if object.use_LOPA:
            errors = evaluation.evaluate_causetree_for_deviationscenario(object)
            extra_context['errors'] = errors
            dependencies = object.dependencies()
            # annotate with number
            i = 1
            for item in dependencies:
                item.number = i
                i += 1
            for item in treeobjects:
                for dep in dependencies:
                    if item == dep.element1 or item == dep.element2:
                        if hasattr(item, 'depnumbers'):
                            item.depnumbers.append(dep.number)
                        else:
                            item.depnumbers = [dep.number]
            table = app_tables.DependenciesTable(dependencies)
            table.title = _('Dependencies')
            if app_models.Dependency.may_add(self.request.user, parent=object):
                table.buttons = [{
                        'url': object.get_add_dependency_url(),
                        'label': _('Add'),
                    }]
            extra_context['table'] = table
        extra_context['treeobjects'] = treeobjects

class display_evaluation(MixIn, base_views.display_evaluation):
    pass

class display_lopa(MixIn, base_views.display_base):
    allow_delete = False
    form_class = app_forms.DeviationScenarioLOPASheet

    def add_to_extra_context(self, extra_context, object):
        super(display_lopa, self).add_to_extra_context(extra_context, object)
        if not self.object.suggestionlist:
            if self.object.use_LOPA:
                errors = evaluation.evaluate_causetree_for_deviationscenario(object)
                if not errors:
                    queryset = object.deviationlopapath_set.all()
                    table = app_tables.DeviationLopaPathTable(queryset, skipcolumns=['scenario','final'])
                    table.title = _('LOPA result')
                    extra_context['table'] = table
            try:
                object.final = app_models.CauseTreeElement.objects.filter(parent__isnull=True, scenario=object).get_versionedobjects(version=object._version)[0]
            except:
                pass

class display(MixIn, crud.TabContainer):
    tabviews = {
        'scenario': display_scenario(),
        'causetree': display_causetree(),
        'evaluation': display_evaluation(),
        'lopa': display_lopa(),
    }
    default = 'scenario'

class edit_scenario(MixIn, base_views.edit_scenario):
    pass

class edit_causetree(MixIn, base_views.edit_causetree):
    template = 'deviations/scenario_causetree_edit.html'

    def togglecause(self, item):
        success = False
        item = int(item)
        if item < 0:
            item = self.tempids.get(item)
        if self.treeelement_class:
            try:
                treeelement = self.treeelement_class.objects.get_versionedobject(v_id=item, version=WorkVersion)
            except self.treeelement_class.DoesNotExist:
                treeelement = None
            if treeelement:
                if treeelement.elementtype == app_models.EVENT_ID:
                    treeelement.content_object.condition = not treeelement.content_object.condition
                    treeelement.content_object.save(self.request.user)
                    success = True
        return success

class edit_evaluation(MixIn, base_views.edit_evaluation):
    pass

class edit_lopa(MixIn, base_views.edit_evaluation):
    '''
    Inheriting from base_views edit_evaluation to keep the items from the
    base_views MixIn class like basetabs
    '''
    form_class = app_forms.DeviationScenarioLOPAForm
    template = 'deviations/scenario_evaluation_edit.html'

class edit(MixIn, crud.TabContainer):
    tabviews = {
        'scenario': edit_scenario(),
        'causetree': edit_causetree(),
        'evaluation': edit_evaluation(),
        'lopa': edit_lopa(),
    }
    default = 'scenario'

class delete(MixIn, base_views.delete):
    pass

class report(MixIn, base_views.report):
    pass

class add_to_scope(MixIn, base_views.add_to_scope):
    pass

class add_to_suggestionlist(MixIn, base_views.add_to_suggestionlist):
    pass

class compare_scenario(MixIn, base_views.compare_scenario):
    form_class = app_forms.DeviationScenarioCompareSheet

class compare_causetree(MixIn, base_views.compare_causetree):
    pass

class compare(MixIn, crud.TabContainer):
    tabviews = {
        'scenario': compare_scenario(),
        'causetree': compare_causetree(),
    }
    default = 'scenario'

class move(MixIn, base_views.move):
    pass

class move_to_sl(MixIn, base_views.move_to_sl):
    slmodel = app_models.DeviationSuggestionlist

class copy(MixIn, base_views.copy):
    pass

class copy_to_sl(MixIn, base_views.copy_to_sl):
    slmodel = app_models.DeviationSuggestionlist

class publish(MixIn, base_views.publish):
    pass

def type_lookup(request):
    return base_views.type_lookup(request, app_models.AppConfig)

def name_lookup(request):
    return base_views.name_lookup(request, app_models.AppConfig)

class ScenarioFilter(MixIn, base_views.ScenarioFilter):
    pass

class ScenarioListObject(MixIn, base_views.ScenarioListObject):
    pass

class scenarios(MixIn, base_views.scenarios):
    filter = ScenarioFilter()
    listobject = ScenarioListObject()

    def get_navigationlist(self, namespace):
        return deviations_localnavigationlist(namespace)

class activate(MixIn, base_views.activate):
    pass

views = {
    'display': display(),
    'edit': edit(),
    'delete': delete(),
    'report': report(),
    'add_to_scope': add_to_scope(),
    'add_to_suggestionlist': add_to_suggestionlist(),
    'compare': compare(),
    'move': move(),
    'move_to_sl': move_to_sl(),
    'copy': copy(),
    'copy_to_sl': copy_to_sl(),
    'publish': publish(),
    'scenarios': scenarios(),
    'type_lookup': type_lookup,
    'name_lookup': name_lookup,
    'activate': activate(),
}


def deviations_localnavigationlist(namespace):
    return [
            {   'name': u'scenarios',
                'url': reverse('%s_scenarios' % namespace),
                'label': _('Scenarios')},
            {   'name': u'protectionlayers',
                'url': reverse('%s_protectionlayers' % namespace),
                'label': _('Protection layers')},
            {   'name': u'measures',
                'url': reverse('%s_measures' % namespace),
                'label': _('Measures')},
            {   'name': u'lopapaths',
                'url': reverse('%s_lopapaths' % namespace),
                'label': _('LOPA scenarios')},
            {   'name': u'attentionpoints',
                'url': reverse('%s_attentionpoints' % namespace),
                'label': _('Attention points')},
        ]






