from analyses.analysisbase import tests as base_tests

from analyses.explosionprotection import models as app_models

from django.contrib.auth.models import User

class PermissionsMixIn(object):
    def setPermissions(self):
        from django.contrib.auth.models import User, Permission
        from django.contrib.contenttypes.models import ContentType
        # give the users permissions

        # authorisations for users:
        # 1 = authorised
        # 2 = unauthorised to edit
        # 3 = unauthorised to even display

        u = User.objects.get(pk=1)

        permissions = [
            ('display_versions','versioning','version'),
            ('display_published_versions','versioning','version'),
            ('edit_versions','versioning','version'),
            ('display_explosionprotectionscenarios','explosionprotection','explosionprotectionscenario'),
            ('edit_explosionprotectionscenarios','explosionprotection','explosionprotectionscenario'),
            ('display_installations','installations','section'),
            ('display_explosionprotectionsuggestionlists','explosionprotection','explosionprotectionsuggestionlist'),
            ('edit_explosionprotectionsuggestionlists','explosionprotection','explosionprotectionsuggestionlist'),
        ]
        for item in permissions:
            u.user_permissions.add(Permission.objects.get_by_natural_key(*item))

        u = User.objects.get(pk=2)
        permissions = [
            ('display_versions','versioning','version'),
            ('display_published_versions','versioning','version'),
            ('display_explosionprotectionscenarios','explosionprotection','explosionprotectionscenario'),
            ('display_installations','installations','section'),
            ('display_explosionprotectionsuggestionlists','explosionprotection','explosionprotectionsuggestionlist'),
        ]
        for item in permissions:
            u.user_permissions.add(Permission.objects.get_by_natural_key(*item))

class SettingsMixIn(object):
    sc_model = app_models.ExplosionProtectionScenario
    ev_model = app_models.ExplosionProtectionEvent
    pl_model = app_models.ExplosionProtectionProtectionLayer
    me_model = app_models.ExplosionProtectionMeasure
    plme_model = app_models.ExplosionProtectionPL_Measure
    ap_model = app_models.ExplosionProtectionAttentionPoint
    sl_model = app_models.ExplosionProtectionSuggestionlist
    apsl_model = app_models.ExplosionProtectionAPSuggestionlist
    tree_model = app_models.ExplosionProtectionTreeElement
    namespace = "explosionprotection"


class ExplosionProtection_SuggestionlistTest(PermissionsMixIn, SettingsMixIn, base_tests.SuggestionlistTest):
    pass

class ExplosionProtection_ScenarioTest(PermissionsMixIn, SettingsMixIn, base_tests.ScenarioTest):
    pass

class ExplosionProtection_EventTest(PermissionsMixIn, SettingsMixIn, base_tests.EventTest):
    pass

class ExplosionProtection_ProtectionLayerTest(PermissionsMixIn, SettingsMixIn, base_tests.ProtectionLayerTest):
    pass

class ExplosionProtection_MeasureTest(PermissionsMixIn, SettingsMixIn, base_tests.MeasureTest):
    pass

class ExplosionProtection_APSuggestionlistTest(PermissionsMixIn, SettingsMixIn, base_tests.APSuggestionlistTest):
    pass

class ExplosionProtection_AttentionPointTest(PermissionsMixIn, SettingsMixIn, base_tests.AttentionPointTest):
    pass

class ExplosionProtection_VersioningTest(PermissionsMixIn, SettingsMixIn, base_tests.VersioningTest):
    pass

class ExplosionProtection_SearchTestCase(PermissionsMixIn, SettingsMixIn, base_tests.SearchTest):
    searchclasses = {
        'sl_search': app_models.ExplosionProtection_SuggestionlistSearch,
        'sc_search': app_models.ExplosionProtection_ScenarioSearch,
        'ev_search': app_models.ExplosionProtection_EventSearch,
        'pl_search': app_models.ExplosionProtection_ProtectionLayerSearch,
        'me_search': app_models.ExplosionProtection_MeasureSearch,
        'apsl_search': app_models.ExplosionProtection_APSuggestionlistSearch,
        'ap_search': app_models.ExplosionProtection_AttentionPointSearch,
        }
