from django.conf.urls import *
from installations.views import main, section, section_substance, section_reaction, scope
from utils.urlhelpers import decorated_patterns
from utils.permissions import permission_required

urlpatterns = decorated_patterns('', permission_required('installations.display_installations'),
    url(r'^$', main.overview(), name='installations'),

    url(r'^overview/$', main.overview(), name='installations_overview'),
    url(r'^overview/pdf/$', main.overview_report(), name='installations_overview_report'),
    url(r'^overview/edit/$', main.overview_edit(), name='installations_overview_edit'),
    url(r'^overview/history/$', main.overview_history(), name='installations_overview_history'),
    url(r'^overview/compare/(?P<version_id>\d+)/$', main.overview_compare(), name='installations_overview_compare'),
    url(r'^tree/json/$', main.tree_json, name='installations_tree_json'),
    url(r'^sections/(?P<object_id>\d+)/delete/$', section.delete(), name='installations_section_delete'),
    url(r'^sections/(?P<object_id>\d+)/pdf/$', section.report(), name='installations_section_report'),
    url(r'^sections/(?P<object_id>\d+)/publish/$', section.publish(), name='installations_section_publish'),
    url(r'^sections/(?P<object_id>\d+)/(?P<tab>\w+)/$', section.display(), name='installations_section'),
    url(r'^sections/(?P<object_id>\d+)/(?P<tab>\w+)/edit/$', section.edit(), name='installations_section_edit'),
    url(r'^sections/add/$', section.add(), name='installations_section_add'),
    url(r'^sections/(?P<object_id>\d+)/section/add/$', section.add_to_section(), name='installations_section_add_section'),
    url(r'^sections/(?P<object_id>\d+)/compare/(?P<version_id>\d+)/$', section.compare(), name='installations_section_compare'),
    url(r'^sections/(?P<object_id>\d+)/scenario/add/$', section.add_scenario(), name='installations_section_add_scenario'),
    url(r'^sections/(?P<object_id>\d+)/scenario/addfromsl/$', section.add_scenario_from_sl(), name='installations_section_add_scenario_from_sl'),

    url(r'^sections/substances/(?P<object_id>\d+)/edit/$', section_substance.edit(), name='installations_section_substance_edit'),
    url(r'^sections/substances/(?P<object_id>\d+)/delete/$', section_substance.delete(), name='installations_section_substance_delete'),
    url(r'^sections/substances/(?P<object_id>\d+)/$', section_substance.display(), name='installations_section_substance'),
    url(r'^sections/(?P<object_id>\d+)/substance/add/$', section_substance.add_to_section(), name='installations_section_add_substance'),
    url(r'^sections/substances/(?P<object_id>\d+)/compare/(?P<version_id>\d+)/$', section_substance.compare(), name='installations_section_substance_compare'),

    url(r'^sections/reactions/(?P<object_id>\d+)/edit/$', section_reaction.edit(), name='installations_section_reaction_edit'),
    url(r'^sections/reactions/(?P<object_id>\d+)/delete/$', section_reaction.delete(), name='installations_section_reaction_delete'),
    url(r'^sections/reactions/(?P<object_id>\d+)/$', section_reaction.display(), name='installations_section_reaction'),
    url(r'^sections/(?P<object_id>\d+)/reaction/add/$', section_reaction.add_to_section(), name='installations_section_add_reaction'),
    url(r'^sections/reactions/(?P<object_id>\d+)/compare/(?P<version_id>\d+)/$', section_reaction.compare(), name='installations_section_reaction_compare'),

    url(r'^scopes/$', scope.scopes(), name='installations_scopes'),
    url(r'^scopes/(?P<object_id>\d+)/(?P<tab>\w+)/edit/$', scope.edit(), name='installations_scope_edit'),
    url(r'^scopes/(?P<object_id>\d+)/delete/$', scope.delete(), name='installations_scope_delete'),
    url(r'^scopes/(?P<object_id>\d+)/pdf/$', scope.report(), name='installations_scope_report'),
    url(r'^scopes/(?P<object_id>\d+)/publish/$', scope.publish(), name='installations_scope_publish'),
    url(r'^scopes/(?P<object_id>\d+)/(?P<tab>\w+)/$', scope.display(), name='installations_scope'),
    url(r'^scopes/add/$', scope.add(), name='installations_scope_add'),
    url(r'^scopes/(?P<object_id>\d+)/compare/(?P<version_id>\d+)/$', scope.compare(), name='installations_scope_compare'),
    url(r'^scopes/(?P<object_id>\d+)/scenario/add/$', scope.add_scenario(), name='installations_scope_add_scenario'),
    url(r'^scopes/(?P<object_id>\d+)/scenario/addfromsl/$', scope.add_scenario_from_sl(), name='installations_scope_add_scenario_from_sl'),

    url(r'^publish/$', main.publish(), name='installations_publish'),
)

