import utils.versioning.models as app_models
from django.utils.translation import ugettext_lazy as _
from utils import tables
from django.conf import settings

class VersionsTable(tables.ModelTable):
    name = tables.Column(
            verbose_name = _('Version'),
            link = lambda x: x.data.get_absolute_url(),
        )
    date = tables.DateColumn(
            verbose_name = _('Date'),
            format = settings.DATETIME_OUTPUT_FORMAT,
        )
    class Meta:
        model = app_models.Version
        columns = ('name', 'date',)

    def get_row_classes(self, row, context):
        result = []
        if row.data.published:
            result.append('fat')
        return result

class ItemsTable(tables.Table):
    itemtype = tables.Column(verbose_name=_('Itemtype'))
    item = tables.Column(
            verbose_name = _('Item'),
            link = lambda x: x.data['item'].get_absolute_url(),
        )
    change = tables.Column( verbose_name = _('Change'))

class ChangedObjectsTable(tables.Table):
    itemtype = tables.Column(verbose_name=_('Itemtype'))
    item = tables.Column(
            verbose_name = _('Item'),
            link = lambda x: hasattr(x.data['item'], 'get_absolute_url') and x.data['item'].get_absolute_url() or u'',
        )
